/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import {Injectable} from '@angular/core';
import {Job} from "../model/job";
import {StorageService} from "../../shared/storage/storage.service";
import {BehaviorSubject, Observable} from "rxjs";

@Injectable({
  providedIn: 'root'
})
export class JobService {

  private jobs: Array<Job> = [];
  private _jobs: BehaviorSubject<Array<Job>> = new BehaviorSubject<Array<Job>>(this.jobs);
  public readonly jobs$: Observable<Array<Job>> = this._jobs.asObservable();
  private readonly endPoint = `jobs`;

  constructor(private storage: StorageService) {
    this.loadJobs();
  }

  /**
   * loadJobs
   */
  loadJobs(): void {
    const loadedJobs = this.storage.getLocal(this.endPoint);
    if (loadedJobs) {
      this.jobs = JSON.parse(loadedJobs) as Array<Job>;
      this._jobs.next(this.jobs);
    }
  }

  /**
   * get a job
   */
  getJob(requestId: number): Job | undefined {
    for (const job of this.jobs) {
      if (job.requestId === requestId) {
        return job;
      }
    }
    return undefined;
  }

  /**
   * create a job
   */
  upsertJob(job: Job): void {
    for (let i = 0; i < this.jobs.length; i++) {
      if (this.jobs[i].requestId === job.requestId) {
        this.jobs.splice(i, 1, job);
        return;
      }
    }
    // if we didn't return already, this job wasn't in the list, so add it
    this.jobs.push(job);
    this._jobs.next(this.jobs);
  }

  /**
   * delete a job
   */
  deleteJob(job: Job): void {
    for (let i = 0; i < this.jobs.length; i++) {
      if (this.jobs[i].requestId === job.requestId) {
        this.jobs.splice(i, 1);
        this._jobs.next(this.jobs);
      }
    }
    throw new Error('Delete failed, that jobs was not found');
  }
}
